/*
Copyright 2021 The Kruise Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

// Code generated by client-gen. DO NOT EDIT.

package v1alpha1

import (
	"time"

	v1alpha1 "github.com/openkruise/kruise-api/apps/v1alpha1"
	scheme "github.com/openkruise/kruise-api/client/clientset/versioned/scheme"
	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	rest "k8s.io/client-go/rest"
)

// NodeImagesGetter has a method to return a NodeImageInterface.
// A group's client should implement this interface.
type NodeImagesGetter interface {
	NodeImages() NodeImageInterface
}

// NodeImageInterface has methods to work with NodeImage resources.
type NodeImageInterface interface {
	Create(*v1alpha1.NodeImage) (*v1alpha1.NodeImage, error)
	Update(*v1alpha1.NodeImage) (*v1alpha1.NodeImage, error)
	UpdateStatus(*v1alpha1.NodeImage) (*v1alpha1.NodeImage, error)
	Delete(name string, options *v1.DeleteOptions) error
	DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
	Get(name string, options v1.GetOptions) (*v1alpha1.NodeImage, error)
	List(opts v1.ListOptions) (*v1alpha1.NodeImageList, error)
	Watch(opts v1.ListOptions) (watch.Interface, error)
	Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.NodeImage, err error)
	NodeImageExpansion
}

// nodeImages implements NodeImageInterface
type nodeImages struct {
	client rest.Interface
}

// newNodeImages returns a NodeImages
func newNodeImages(c *AppsV1alpha1Client) *nodeImages {
	return &nodeImages{
		client: c.RESTClient(),
	}
}

// Get takes name of the nodeImage, and returns the corresponding nodeImage object, and an error if there is any.
func (c *nodeImages) Get(name string, options v1.GetOptions) (result *v1alpha1.NodeImage, err error) {
	result = &v1alpha1.NodeImage{}
	err = c.client.Get().
		Resource("nodeimages").
		Name(name).
		VersionedParams(&options, scheme.ParameterCodec).
		Do().
		Into(result)
	return
}

// List takes label and field selectors, and returns the list of NodeImages that match those selectors.
func (c *nodeImages) List(opts v1.ListOptions) (result *v1alpha1.NodeImageList, err error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	result = &v1alpha1.NodeImageList{}
	err = c.client.Get().
		Resource("nodeimages").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Do().
		Into(result)
	return
}

// Watch returns a watch.Interface that watches the requested nodeImages.
func (c *nodeImages) Watch(opts v1.ListOptions) (watch.Interface, error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	opts.Watch = true
	return c.client.Get().
		Resource("nodeimages").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Watch()
}

// Create takes the representation of a nodeImage and creates it.  Returns the server's representation of the nodeImage, and an error, if there is any.
func (c *nodeImages) Create(nodeImage *v1alpha1.NodeImage) (result *v1alpha1.NodeImage, err error) {
	result = &v1alpha1.NodeImage{}
	err = c.client.Post().
		Resource("nodeimages").
		Body(nodeImage).
		Do().
		Into(result)
	return
}

// Update takes the representation of a nodeImage and updates it. Returns the server's representation of the nodeImage, and an error, if there is any.
func (c *nodeImages) Update(nodeImage *v1alpha1.NodeImage) (result *v1alpha1.NodeImage, err error) {
	result = &v1alpha1.NodeImage{}
	err = c.client.Put().
		Resource("nodeimages").
		Name(nodeImage.Name).
		Body(nodeImage).
		Do().
		Into(result)
	return
}

// UpdateStatus was generated because the type contains a Status member.
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().

func (c *nodeImages) UpdateStatus(nodeImage *v1alpha1.NodeImage) (result *v1alpha1.NodeImage, err error) {
	result = &v1alpha1.NodeImage{}
	err = c.client.Put().
		Resource("nodeimages").
		Name(nodeImage.Name).
		SubResource("status").
		Body(nodeImage).
		Do().
		Into(result)
	return
}

// Delete takes name of the nodeImage and deletes it. Returns an error if one occurs.
func (c *nodeImages) Delete(name string, options *v1.DeleteOptions) error {
	return c.client.Delete().
		Resource("nodeimages").
		Name(name).
		Body(options).
		Do().
		Error()
}

// DeleteCollection deletes a collection of objects.
func (c *nodeImages) DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error {
	var timeout time.Duration
	if listOptions.TimeoutSeconds != nil {
		timeout = time.Duration(*listOptions.TimeoutSeconds) * time.Second
	}
	return c.client.Delete().
		Resource("nodeimages").
		VersionedParams(&listOptions, scheme.ParameterCodec).
		Timeout(timeout).
		Body(options).
		Do().
		Error()
}

// Patch applies the patch and returns the patched nodeImage.
func (c *nodeImages) Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.NodeImage, err error) {
	result = &v1alpha1.NodeImage{}
	err = c.client.Patch(pt).
		Resource("nodeimages").
		SubResource(subresources...).
		Name(name).
		Body(data).
		Do().
		Into(result)
	return
}
