/*
Copyright 2021 The Kruise Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

// Code generated by client-gen. DO NOT EDIT.

package v1alpha1

import (
	"time"

	v1alpha1 "github.com/openkruise/kruise-api/apps/v1alpha1"
	scheme "github.com/openkruise/kruise-api/client/clientset/versioned/scheme"
	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	rest "k8s.io/client-go/rest"
)

// ResourceDistributionsGetter has a method to return a ResourceDistributionInterface.
// A group's client should implement this interface.
type ResourceDistributionsGetter interface {
	ResourceDistributions() ResourceDistributionInterface
}

// ResourceDistributionInterface has methods to work with ResourceDistribution resources.
type ResourceDistributionInterface interface {
	Create(*v1alpha1.ResourceDistribution) (*v1alpha1.ResourceDistribution, error)
	Update(*v1alpha1.ResourceDistribution) (*v1alpha1.ResourceDistribution, error)
	UpdateStatus(*v1alpha1.ResourceDistribution) (*v1alpha1.ResourceDistribution, error)
	Delete(name string, options *v1.DeleteOptions) error
	DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
	Get(name string, options v1.GetOptions) (*v1alpha1.ResourceDistribution, error)
	List(opts v1.ListOptions) (*v1alpha1.ResourceDistributionList, error)
	Watch(opts v1.ListOptions) (watch.Interface, error)
	Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.ResourceDistribution, err error)
	ResourceDistributionExpansion
}

// resourceDistributions implements ResourceDistributionInterface
type resourceDistributions struct {
	client rest.Interface
}

// newResourceDistributions returns a ResourceDistributions
func newResourceDistributions(c *AppsV1alpha1Client) *resourceDistributions {
	return &resourceDistributions{
		client: c.RESTClient(),
	}
}

// Get takes name of the resourceDistribution, and returns the corresponding resourceDistribution object, and an error if there is any.
func (c *resourceDistributions) Get(name string, options v1.GetOptions) (result *v1alpha1.ResourceDistribution, err error) {
	result = &v1alpha1.ResourceDistribution{}
	err = c.client.Get().
		Resource("resourcedistributions").
		Name(name).
		VersionedParams(&options, scheme.ParameterCodec).
		Do().
		Into(result)
	return
}

// List takes label and field selectors, and returns the list of ResourceDistributions that match those selectors.
func (c *resourceDistributions) List(opts v1.ListOptions) (result *v1alpha1.ResourceDistributionList, err error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	result = &v1alpha1.ResourceDistributionList{}
	err = c.client.Get().
		Resource("resourcedistributions").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Do().
		Into(result)
	return
}

// Watch returns a watch.Interface that watches the requested resourceDistributions.
func (c *resourceDistributions) Watch(opts v1.ListOptions) (watch.Interface, error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	opts.Watch = true
	return c.client.Get().
		Resource("resourcedistributions").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Watch()
}

// Create takes the representation of a resourceDistribution and creates it.  Returns the server's representation of the resourceDistribution, and an error, if there is any.
func (c *resourceDistributions) Create(resourceDistribution *v1alpha1.ResourceDistribution) (result *v1alpha1.ResourceDistribution, err error) {
	result = &v1alpha1.ResourceDistribution{}
	err = c.client.Post().
		Resource("resourcedistributions").
		Body(resourceDistribution).
		Do().
		Into(result)
	return
}

// Update takes the representation of a resourceDistribution and updates it. Returns the server's representation of the resourceDistribution, and an error, if there is any.
func (c *resourceDistributions) Update(resourceDistribution *v1alpha1.ResourceDistribution) (result *v1alpha1.ResourceDistribution, err error) {
	result = &v1alpha1.ResourceDistribution{}
	err = c.client.Put().
		Resource("resourcedistributions").
		Name(resourceDistribution.Name).
		Body(resourceDistribution).
		Do().
		Into(result)
	return
}

// UpdateStatus was generated because the type contains a Status member.
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().

func (c *resourceDistributions) UpdateStatus(resourceDistribution *v1alpha1.ResourceDistribution) (result *v1alpha1.ResourceDistribution, err error) {
	result = &v1alpha1.ResourceDistribution{}
	err = c.client.Put().
		Resource("resourcedistributions").
		Name(resourceDistribution.Name).
		SubResource("status").
		Body(resourceDistribution).
		Do().
		Into(result)
	return
}

// Delete takes name of the resourceDistribution and deletes it. Returns an error if one occurs.
func (c *resourceDistributions) Delete(name string, options *v1.DeleteOptions) error {
	return c.client.Delete().
		Resource("resourcedistributions").
		Name(name).
		Body(options).
		Do().
		Error()
}

// DeleteCollection deletes a collection of objects.
func (c *resourceDistributions) DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error {
	var timeout time.Duration
	if listOptions.TimeoutSeconds != nil {
		timeout = time.Duration(*listOptions.TimeoutSeconds) * time.Second
	}
	return c.client.Delete().
		Resource("resourcedistributions").
		VersionedParams(&listOptions, scheme.ParameterCodec).
		Timeout(timeout).
		Body(options).
		Do().
		Error()
}

// Patch applies the patch and returns the patched resourceDistribution.
func (c *resourceDistributions) Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.ResourceDistribution, err error) {
	result = &v1alpha1.ResourceDistribution{}
	err = c.client.Patch(pt).
		Resource("resourcedistributions").
		SubResource(subresources...).
		Name(name).
		Body(data).
		Do().
		Into(result)
	return
}
