/*
Copyright 2021 The Kruise Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

// Code generated by client-gen. DO NOT EDIT.

package v1alpha1

import (
	"time"

	v1alpha1 "github.com/openkruise/kruise-api/apps/v1alpha1"
	scheme "github.com/openkruise/kruise-api/client/clientset/versioned/scheme"
	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	rest "k8s.io/client-go/rest"
)

// SidecarSetsGetter has a method to return a SidecarSetInterface.
// A group's client should implement this interface.
type SidecarSetsGetter interface {
	SidecarSets() SidecarSetInterface
}

// SidecarSetInterface has methods to work with SidecarSet resources.
type SidecarSetInterface interface {
	Create(*v1alpha1.SidecarSet) (*v1alpha1.SidecarSet, error)
	Update(*v1alpha1.SidecarSet) (*v1alpha1.SidecarSet, error)
	UpdateStatus(*v1alpha1.SidecarSet) (*v1alpha1.SidecarSet, error)
	Delete(name string, options *v1.DeleteOptions) error
	DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
	Get(name string, options v1.GetOptions) (*v1alpha1.SidecarSet, error)
	List(opts v1.ListOptions) (*v1alpha1.SidecarSetList, error)
	Watch(opts v1.ListOptions) (watch.Interface, error)
	Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.SidecarSet, err error)
	SidecarSetExpansion
}

// sidecarSets implements SidecarSetInterface
type sidecarSets struct {
	client rest.Interface
}

// newSidecarSets returns a SidecarSets
func newSidecarSets(c *AppsV1alpha1Client) *sidecarSets {
	return &sidecarSets{
		client: c.RESTClient(),
	}
}

// Get takes name of the sidecarSet, and returns the corresponding sidecarSet object, and an error if there is any.
func (c *sidecarSets) Get(name string, options v1.GetOptions) (result *v1alpha1.SidecarSet, err error) {
	result = &v1alpha1.SidecarSet{}
	err = c.client.Get().
		Resource("sidecarsets").
		Name(name).
		VersionedParams(&options, scheme.ParameterCodec).
		Do().
		Into(result)
	return
}

// List takes label and field selectors, and returns the list of SidecarSets that match those selectors.
func (c *sidecarSets) List(opts v1.ListOptions) (result *v1alpha1.SidecarSetList, err error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	result = &v1alpha1.SidecarSetList{}
	err = c.client.Get().
		Resource("sidecarsets").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Do().
		Into(result)
	return
}

// Watch returns a watch.Interface that watches the requested sidecarSets.
func (c *sidecarSets) Watch(opts v1.ListOptions) (watch.Interface, error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	opts.Watch = true
	return c.client.Get().
		Resource("sidecarsets").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Watch()
}

// Create takes the representation of a sidecarSet and creates it.  Returns the server's representation of the sidecarSet, and an error, if there is any.
func (c *sidecarSets) Create(sidecarSet *v1alpha1.SidecarSet) (result *v1alpha1.SidecarSet, err error) {
	result = &v1alpha1.SidecarSet{}
	err = c.client.Post().
		Resource("sidecarsets").
		Body(sidecarSet).
		Do().
		Into(result)
	return
}

// Update takes the representation of a sidecarSet and updates it. Returns the server's representation of the sidecarSet, and an error, if there is any.
func (c *sidecarSets) Update(sidecarSet *v1alpha1.SidecarSet) (result *v1alpha1.SidecarSet, err error) {
	result = &v1alpha1.SidecarSet{}
	err = c.client.Put().
		Resource("sidecarsets").
		Name(sidecarSet.Name).
		Body(sidecarSet).
		Do().
		Into(result)
	return
}

// UpdateStatus was generated because the type contains a Status member.
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().

func (c *sidecarSets) UpdateStatus(sidecarSet *v1alpha1.SidecarSet) (result *v1alpha1.SidecarSet, err error) {
	result = &v1alpha1.SidecarSet{}
	err = c.client.Put().
		Resource("sidecarsets").
		Name(sidecarSet.Name).
		SubResource("status").
		Body(sidecarSet).
		Do().
		Into(result)
	return
}

// Delete takes name of the sidecarSet and deletes it. Returns an error if one occurs.
func (c *sidecarSets) Delete(name string, options *v1.DeleteOptions) error {
	return c.client.Delete().
		Resource("sidecarsets").
		Name(name).
		Body(options).
		Do().
		Error()
}

// DeleteCollection deletes a collection of objects.
func (c *sidecarSets) DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error {
	var timeout time.Duration
	if listOptions.TimeoutSeconds != nil {
		timeout = time.Duration(*listOptions.TimeoutSeconds) * time.Second
	}
	return c.client.Delete().
		Resource("sidecarsets").
		VersionedParams(&listOptions, scheme.ParameterCodec).
		Timeout(timeout).
		Body(options).
		Do().
		Error()
}

// Patch applies the patch and returns the patched sidecarSet.
func (c *sidecarSets) Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.SidecarSet, err error) {
	result = &v1alpha1.SidecarSet{}
	err = c.client.Patch(pt).
		Resource("sidecarsets").
		SubResource(subresources...).
		Name(name).
		Body(data).
		Do().
		Into(result)
	return
}
