/*
Copyright 2021 The Kruise Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

// Code generated by client-gen. DO NOT EDIT.

package v1alpha1

import (
	"time"

	v1alpha1 "github.com/openkruise/kruise-api/apps/v1alpha1"
	scheme "github.com/openkruise/kruise-api/client/clientset/versioned/scheme"
	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	rest "k8s.io/client-go/rest"
)

// WorkloadSpreadsGetter has a method to return a WorkloadSpreadInterface.
// A group's client should implement this interface.
type WorkloadSpreadsGetter interface {
	WorkloadSpreads(namespace string) WorkloadSpreadInterface
}

// WorkloadSpreadInterface has methods to work with WorkloadSpread resources.
type WorkloadSpreadInterface interface {
	Create(*v1alpha1.WorkloadSpread) (*v1alpha1.WorkloadSpread, error)
	Update(*v1alpha1.WorkloadSpread) (*v1alpha1.WorkloadSpread, error)
	UpdateStatus(*v1alpha1.WorkloadSpread) (*v1alpha1.WorkloadSpread, error)
	Delete(name string, options *v1.DeleteOptions) error
	DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
	Get(name string, options v1.GetOptions) (*v1alpha1.WorkloadSpread, error)
	List(opts v1.ListOptions) (*v1alpha1.WorkloadSpreadList, error)
	Watch(opts v1.ListOptions) (watch.Interface, error)
	Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.WorkloadSpread, err error)
	WorkloadSpreadExpansion
}

// workloadSpreads implements WorkloadSpreadInterface
type workloadSpreads struct {
	client rest.Interface
	ns     string
}

// newWorkloadSpreads returns a WorkloadSpreads
func newWorkloadSpreads(c *AppsV1alpha1Client, namespace string) *workloadSpreads {
	return &workloadSpreads{
		client: c.RESTClient(),
		ns:     namespace,
	}
}

// Get takes name of the workloadSpread, and returns the corresponding workloadSpread object, and an error if there is any.
func (c *workloadSpreads) Get(name string, options v1.GetOptions) (result *v1alpha1.WorkloadSpread, err error) {
	result = &v1alpha1.WorkloadSpread{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("workloadspreads").
		Name(name).
		VersionedParams(&options, scheme.ParameterCodec).
		Do().
		Into(result)
	return
}

// List takes label and field selectors, and returns the list of WorkloadSpreads that match those selectors.
func (c *workloadSpreads) List(opts v1.ListOptions) (result *v1alpha1.WorkloadSpreadList, err error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	result = &v1alpha1.WorkloadSpreadList{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("workloadspreads").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Do().
		Into(result)
	return
}

// Watch returns a watch.Interface that watches the requested workloadSpreads.
func (c *workloadSpreads) Watch(opts v1.ListOptions) (watch.Interface, error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	opts.Watch = true
	return c.client.Get().
		Namespace(c.ns).
		Resource("workloadspreads").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Watch()
}

// Create takes the representation of a workloadSpread and creates it.  Returns the server's representation of the workloadSpread, and an error, if there is any.
func (c *workloadSpreads) Create(workloadSpread *v1alpha1.WorkloadSpread) (result *v1alpha1.WorkloadSpread, err error) {
	result = &v1alpha1.WorkloadSpread{}
	err = c.client.Post().
		Namespace(c.ns).
		Resource("workloadspreads").
		Body(workloadSpread).
		Do().
		Into(result)
	return
}

// Update takes the representation of a workloadSpread and updates it. Returns the server's representation of the workloadSpread, and an error, if there is any.
func (c *workloadSpreads) Update(workloadSpread *v1alpha1.WorkloadSpread) (result *v1alpha1.WorkloadSpread, err error) {
	result = &v1alpha1.WorkloadSpread{}
	err = c.client.Put().
		Namespace(c.ns).
		Resource("workloadspreads").
		Name(workloadSpread.Name).
		Body(workloadSpread).
		Do().
		Into(result)
	return
}

// UpdateStatus was generated because the type contains a Status member.
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().

func (c *workloadSpreads) UpdateStatus(workloadSpread *v1alpha1.WorkloadSpread) (result *v1alpha1.WorkloadSpread, err error) {
	result = &v1alpha1.WorkloadSpread{}
	err = c.client.Put().
		Namespace(c.ns).
		Resource("workloadspreads").
		Name(workloadSpread.Name).
		SubResource("status").
		Body(workloadSpread).
		Do().
		Into(result)
	return
}

// Delete takes name of the workloadSpread and deletes it. Returns an error if one occurs.
func (c *workloadSpreads) Delete(name string, options *v1.DeleteOptions) error {
	return c.client.Delete().
		Namespace(c.ns).
		Resource("workloadspreads").
		Name(name).
		Body(options).
		Do().
		Error()
}

// DeleteCollection deletes a collection of objects.
func (c *workloadSpreads) DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error {
	var timeout time.Duration
	if listOptions.TimeoutSeconds != nil {
		timeout = time.Duration(*listOptions.TimeoutSeconds) * time.Second
	}
	return c.client.Delete().
		Namespace(c.ns).
		Resource("workloadspreads").
		VersionedParams(&listOptions, scheme.ParameterCodec).
		Timeout(timeout).
		Body(options).
		Do().
		Error()
}

// Patch applies the patch and returns the patched workloadSpread.
func (c *workloadSpreads) Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.WorkloadSpread, err error) {
	result = &v1alpha1.WorkloadSpread{}
	err = c.client.Patch(pt).
		Namespace(c.ns).
		Resource("workloadspreads").
		SubResource(subresources...).
		Name(name).
		Body(data).
		Do().
		Into(result)
	return
}
